
#include "../config.h"
#include "yodlpost.h"

void usage()
{
    char const *program = args_programName();

    fprintf(stderr, "%s%s%s%s%s%s%s",
"\n"
"Your Own Document Language: ",
    program,
" " VERSION "\n"
"Usage: ",
    program,
" [options] index yodlout [out]\n"
"Where:\n"
"    [options]   options. Select from\n"
"       -l linesize: maximum length of lines in the index file "
                                                        "(default: 1000)\n"
"       -x ext: extension of the out-files if different from the extension\n"
"               of `out' itself. If omitted, and `out' has no extension,\n"
"               ypp (Yodl Post Processor) is used.\n"
"    index:      the name of the index file generated by Yodl\n"
"    yodlout:    the name of the output file generated by Yodl\n"
"    [out]:      optional name of the file generated by ",
    program,
",\n"
"                stdout if omitted.\n"
"\n"
"The special tags in the index file are processed.\n"
"Normally, this program is run from a yodl2xxx script\n"
"\n"
);

    exit(1);
}
