#include "lexer.ih"

char *l_token_name[] =
{
    "TOKEN_UNKNOWN",

    "TOKEN_SYMBOL",
    "TOKEN_TEXT",
    "TOKEN_PLAINCHAR",
    "TOKEN_OPENPAR",
    "TOKEN_CLOSEPAR",
    "TOKEN_PLUS",

    "TOKEN_SPACE",
    "TOKEN_NEWLINE",

    "TOKEN_EOR",
    "TOKEN_EOF",
};
